@@ -1,5 +1,5 @@
 # flake8: noqa
-keysymdef = {
+key_symbols = {
     "0": 48,
     "1": 49,
     "2": 50,
